==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_el_GR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el_GR">
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.ui" line="44"/>
        <source>Click to access this device from other applications.</source>
        <translation>Κλίκ για πρόσβαση σε αυτή τη συσκευή από άλλες εφαρμογές.</translation>
    </message>
    <message>
        <location filename="../menudiskitem.ui" line="54"/>
        <source>Click to eject this disc.</source>
        <translation>Κλίκ για αποβολή αυτού του δίσκου.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../mountbutton.cpp" line="149"/>
        <source>Removable media/devices manager</source>
        <translation>Διαχειριστής αφαιρούμενων μέσων/συσκευών</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="187"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Συνδέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="205"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Αφαιρέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="233"/>
        <source>No devices Available.</source>
        <translation>Καμία διαθέσιμη συσκευή.</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <location filename="../razormountconfiguration.ui" line="14"/>
        <source>Razor Removable media manager settings</source>
        <translation>Διαχειριστής ρυθμίσεων αφαιρούμενων μέσων στο Razor</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Συμπεριφορά</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>Όταν μια συσκευή συνδέεται </translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="44"/>
        <source>Popup menu</source>
        <translation>Αναδυόμενο μενού</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="45"/>
        <source>Show info</source>
        <translation>Εμφάνιση πληροφοριών</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="46"/>
        <source>Do nothing</source>
        <translation>Καμία ενέργεια</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Κλίκ για πρόσβαση σε αυτή τη συσκευή από άλλες εφαρμογές.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Κλίκ για εξαγωγή αυτού του δίσκου.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Διαχειριστής αφαιρούμενων μέσων/συσκευών</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Συνδέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Αφαιρέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation>Μη διαθέσιμες συσκευές</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Ρυθμίσεις διαχειριστή αφαιρούμενων μέσων Razor</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Συμπεριφορά</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Όταν μια συσκευή συνδέεται </translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Αναδυόμενο μενού</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Εμφάνιση πληροφοριών</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Καμία ενέργεια</translation>
    </message>
</context>
</TS>
